Just a cleanup, __nf_unregister_net_hook() is used by a follow up patch
when handling NFPROTO_INET as a real family from the core.

Signed-off-by: Pablo Neira Ayuso <[email protected]>
---
 net/netfilter/core.c | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/net/netfilter/core.c b/net/netfilter/core.c
index aeb7a4f8f080..d5e0961fd9f3 100644
--- a/net/netfilter/core.c
+++ b/net/netfilter/core.c
@@ -320,7 +320,7 @@ int nf_register_net_hook(struct net *net, const struct 
nf_hook_ops *reg)
 EXPORT_SYMBOL(nf_register_net_hook);
 
 /*
  * __nf_unregister_net_hook - remove a hook from blob
  *
  * @oldp: current address of hook blob
  * @unreg: hook to unregister
@@ -328,8 +328,8 @@ EXPORT_SYMBOL(nf_register_net_hook);
  * This cannot fail, hook unregistration must always succeed.
  * Therefore replace the to-be-removed hook with a dummy hook.
  */
-static void __nf_unregister_net_hook(struct nf_hook_entries *old,
-                                    const struct nf_hook_ops *unreg)
+static void nf_remove_net_hook(struct nf_hook_entries *old,
+                              const struct nf_hook_ops *unreg)
 {
        struct nf_hook_ops **orig_ops;
        bool found = false;
@@ -376,7 +376,7 @@ void nf_unregister_net_hook(struct net *net, const struct 
nf_hook_ops *reg)
                return;
        }
 
-       __nf_unregister_net_hook(p, reg);
+       nf_remove_net_hook(p, reg);
 
        p = __nf_hook_entries_try_shrink(pp);
        mutex_unlock(&nf_hook_mutex);
@@ -429,7 +429,7 @@ void nf_unregister_net_hooks(struct net *net, const struct 
nf_hook_ops *reg,
                p = nf_entry_dereference(*pp);
                if (WARN_ON_ONCE(!p))
                        continue;
-               __nf_unregister_net_hook(p, &reg[i]);
+               nf_remove_net_hook(p, &reg[i]);
        }
        mutex_unlock(&nf_hook_mutex);
 
@@ -320,7 +320,7 @@ int nf_register_net_hook(struct net *net, const struct 
 
 /*
- * __nf_unregister_net_hook - remove a hook from blob
+ * nf_remove_net_hook - remove a hook from blob
  *
  * @oldp: current address of hook blob
-- 
2.11.0

--
To unsubscribe from this list: send the line "unsubscribe netfilter-devel" in
the body of a message to [email protected]
More majordomo info at  http://vger.kernel.org/majordomo-info.html

Reply via email to